          <section class="m-doc-details" id="{{ var.id }}"><div>
            <h3>
              {% if compound.templates != None or var.templates != None  %}
              {% if var.include %}
              <div class="m-doc-include m-code m-inverted m-right-m m-text-right"><span class="cp">#include</span> <a class="cpf" href="{{ var.include[1] }}">{{ var.include[0] }}</a></div>
              {% endif %}
              <div class="m-doc-template">
                {% if compound.templates != None %}
                {% set j = joiner(', ') %}
                template&lt;<span class="m-doc-template-params{% if compound.templates|length >= 3 %} m-doc-template-long{% endif %}">{% for t in compound.templates %}{{ j() }}<span class="m-doc-template-param">{{ t.type }} {% if t.name %}{{ t.name }}{% else %}_{{ loop.index }}{% endif %}</span>{% endfor %}</span>&gt;
                {% endif %}
                {% if compound.templates != None and var.templates != None %}
                <br>
                {% endif %}
                {% if var.templates != None %}
                {% set j = joiner(', ') %}
                template&lt;<span class="m-doc-template-params{% if var.templates|length >= 3 %} m-doc-template-long{% endif %}">{% for t in var.templates %}{{ j() }}<span class="m-doc-template-param">{{ t.type }}{% if t.name %} {{ t.name }}{% endif %}{% if t.default %} = {{ t.default }}{% endif %}</span>{% endfor %}</span>&gt;
                {% endif %}
              </div>
              {% endif %}
              {%+ if var.is_static %}static {% endif %}{{ var.type }} {{ prefix }}<a href="#{{ var.id }}" class="m-doc-self">{{ var.name }}</a>{% if var.is_protected %} <span class="m-label m-warning">protected</span>{% endif %}{% if var.is_constexpr %} <span class="m-label m-primary">constexpr</span>{% endif %}{% if var.is_constinit %} <span class="m-label m-primary">constinit</span>{% endif %}{% if var.since %} {{ var.since }}{% endif %}
              {# the empty line needs to be here to prevent the lines from merging #}

              {% if var.include and compound.templates == None and var.templates == None %}
              <div class="m-doc-include m-code m-inverted m-text-right"><span class="cp">#include</span> <a class="cpf" href="{{ var.include[1] }}">{{ var.include[0] }}</a></div>
              {% endif %}
            </h3>
            {% if var.brief %}
            <p>{{ var.brief }}</p>
            {% endif %}
            {% if var.has_template_details %}
            <table class="m-table m-fullwidth m-flat">
              <thead>
                <tr><th colspan="2">Template parameters</th></tr>
              </thead>
              <tbody>
                {% for template in var.templates|selectattr('name') %}
                <tr>
                  <td{% if loop.index == 1 %} style="width: 1%"{% endif %}>{{ template.name }}</td>
                  <td>{{ template.description }}</td>
                </tr>
                {% endfor %}
              </tbody>
            </table>
            {% endif %}
            {% if var.description %}
{{ var.description }}
            {% endif %}
          </div></section>
